@@ -11,10 +11,13 @@ local function isValidFunctionPos(source, offset)
     return false
 end
 
-return function (ast, position, accept)
+return function (state, position, accept)
     local len = math.huge
     local result
-    guide.eachSourceContain(ast.ast, position, function (source)
+    guide.eachSourceContain(state.ast, position, function (source)
+        if source.virtual then
+            return
+        end
         if source.type == 'function' then
             if not isValidFunctionPos(source, position) then
                 return
